#!/bin/sh
# Adapted Aacraid monitoring script 
# for LSI - Megaraid2 on RedhatEnt3 
# by:
# patricko@staff.singnet.com.sg, 2005 Aug
#
# version 1.0.1
# required: ut_linux_megarc_1.11.zip 
# license: beerware - need to buy me a beer if you adopt it
#

workdir=/usr/local/cron_dir/megaraid2
raidcmd=/usr/local/cron_dir/megaraid2/megarc
diffcmd=/usr/bin/diff
catcmd=/bin/cat
smailcmd=/usr/sbin/sendmail
egrepcmd=/bin/egrep
teecmd=/usr/bin/tee
msglog=/var/log/messages

####Display Conf and Raid Status
raidcommands="-dispCfg -a0"
####Display Physical setup
#raidcommands="-LogPhysInfo -alladp"

host=`hostname`
admin="mail-team@staff.singnet.com.sg"

currConf=raid.current.config
prodConf=raid.production.config

currLog=megarc.log
prodLog=megarc.production.log

#
# check 1 - raid status
#
cd $workdir
rm -f raid.current.config
$raidcmd $raidcommands | $teecmd $currConf

### check condition 1.1 on Conf
if [ ! -f "$prodConf" ]; then
  echo "Warning: Production config not found, creating new."
  cp -vp $currConf $prodConf
  echo
else

  curdiff=`$diffcmd $currConf $prodConf`
  raiderr=`$catcmd $currConf`
  raidpro=`$catcmd $prodConf`
fi

### check condition 1.2 on Log
if [ ! -f "$prodLog" ]; then
  echo "Warning: Production log not found, creating new."
  cp -vp $currLog $prodLog
  echo
else

  curdiff2=`$diffcmd $currLog $prodLog`
  raiderr2=`$catcmd $currLog`
  raidpro2=`$catcmd $prodLog`
fi


### report for condition 1.1
if [ "$curdiff" != "" ] ; then
  $smailcmd -f devnull@$host -t << RedCatSun
To: $admin
From: root@$host     
Subject: Raid inconsistency on $host. 
Errors-To: devnull

====> A diff between production and current is:
$curdiff


========================================
= Current container list and disk list =
========================================
$raiderr

===========================================
= Production container list and disk list =
===========================================
$raidpro

RedCatSun

fi

### report for condition 1.2
if [ "$curdiff2" != "" ] ; then
  $smailcmd -f devnull@$host -t << RedCatSun2
To: $admin
From: root@$host     
Subject: Raid inconsistency on $host. 
Errors-To: devnull

====> A diff between production and current is:
$curdiff2


========================================
= Current container list and disk list =
========================================
$raiderr2

===========================================
= Production container list and disk list =
===========================================
$raidpro2

RedCatSun2

fi

#
#  Check 2 - raid err msg (bad sectors) 
#            ssh / other err msg
#            from /var/log/messages
#            

#  The next check is just looking for scsi or error: messages in /var/log/messages
#
#  Raid error messages look something like the following:
#
#  eg: #####DEPRECATED#####
#  AAC:Drive 0:2:0 offline on container 0:
#  AAC:RAID5 Failover Container 0 No Failover Assigned

#AACerr=`$egrepcmd "(AAC|aacraid):" $msglog`
ARAIDerr=""
egrep -i "(fail|scsi|error)" /var/log/messages |egrep -i "(fail|err)" |grep "`date '+%b %e'`" > $workdir/raid.msg.tmp

if [ -s $workdir/raid.msg.tmp ]; then
  if [ -f $workdir/raid.msg ]; then
    diff $workdir/raid.msg $workdir/raid.msg.tmp > /dev/null 2>&1

    ## different
    if [ $? -ne 0 ]; then
      mv -v $workdir/raid.msg.tmp $workdir/raid.msg
      ARAIDerr=`cat $workdir/raid.msg`
    else
    ## same
      rm -f $workdir/raid.msg.tmp
    fi

  else
     mv -v $workdir/raid.msg.tmp $workdir/raid.msg
     ARAIDerr=`cat $workdir/raid.msg`
  fi
else
  rm -f $workdir/raid.msg
  rm -f $workdir/raid.msg.tmp
fi 

if [ "$ARAIDerr" != "" ] ; then
   $smailcmd -f devnull@$host -t << RedDogSun
To: $admin
From: root@$host       
Subject: Possible Raid inconsistency / Errors on $host. 
Errors-To: devnull

====> A grep for scsi error / other error: in /var/log/messages:
$ARAIDerr

RedDogSun
fi

exit 0

